@@ -3,7 +3,7 @@ from datamodel_code_generator.imports import Import
 IMPORT_CONSTR = Import.from_full_path('pydantic.constr')
 IMPORT_CONINT = Import.from_full_path('pydantic.conint')
 IMPORT_CONFLOAT = Import.from_full_path('pydantic.confloat')
-IMPORT_CONDECIMAL = Import.from_full_path('pydantic.condeciaml')
+IMPORT_CONDECIMAL = Import.from_full_path('pydantic.condecimal')
 IMPORT_POSITIVE_INT = Import.from_full_path('pydantic.PositiveInt')
 IMPORT_NEGATIVE_INT = Import.from_full_path('pydantic.NegativeInt')
 IMPORT_POSITIVE_FLOAT = Import.from_full_path('pydantic.PositiveFloat')
